@@ -108,7 +108,6 @@ setMethodS3("as.character", "AbstractCurveNormalization", function(x, ...) {
   this <- x;
 
   s <- sprintf("%s:", class(this)[1]);
-
   dsList <- getDataSets(this);
   s <- c(s, sprintf("Data sets (%d):", length(dsList)));
   for (kk in seq_along(dsList)) {
@@ -116,9 +115,7 @@ setMethodS3("as.character", "AbstractCurveNormalization", function(x, ...) {
     s <- c(s, sprintf("<%s>:", capitalize(names(dsList)[kk])));
     s <- c(s, as.character(ds));
   }
-
-  class(s) <- "GenericSummary";
-  s;
+  GenericSummary(s);
 }, protected=TRUE)
 
 
@@ -444,7 +441,7 @@ setMethodS3("process", "AbstractCurveNormalization", function(this, ..., force=F
         verbose && cat(verbose, "Already copied: ", pathname);
       } else {
         verbose && cat(verbose, "Output pathname: ", pathname);
-        copyFile(getPathname(dfT), pathname, verbose=less(verbose,50));
+        copyFile(getPathname(dfT), pathname, copy.mode=FALSE, verbose=less(verbose,50));
       }
       # Not needed anymore
       filename <- pathname <- NULL;
@@ -619,6 +616,10 @@ setMethodS3("process", "AbstractCurveNormalization", function(this, ..., force=F
 
 ############################################################################
 # HISTORY:
+# 2014-09-04
+# o ROBUSTNESS: It could be that process() for AbstractCurveNormalization
+#   would generate an error due to read-only permissions introduced
+#   by copying the target file without resetting the file permissions.
 # 2012-04-16
 # o DOCUMENTATION: Removed reference to aroma.light::fitPrincipalCurve().
 # 2010-01-05
