@@ -24,11 +24,11 @@ setConstructorS3("XYCurveNormalization", function(...) {
 })
 
 setMethodS3("fitOne", "XYCurveNormalization", function(this, theta, ...) {
-  fitXYCurve(theta, ...);
+  .fitXYCurve(theta, ...);
 }, protected=TRUE)
 
 setMethodS3("backtransformOne", "XYCurveNormalization", function(this, theta, fit, ...) {
-  backtransformXYCurve(theta, fit=fit, ...);
+  .backtransformXYCurve(theta, fit=fit, ...);
 }, protected=TRUE)
 
 
